Index: media/filters/chunk_demuxer.h |
diff --git a/media/filters/chunk_demuxer.h b/media/filters/chunk_demuxer.h |
index 7be515261a7c7e4a1c3c0377e06d8e0a5e6d202c..38bf7bcd6800b53e4a0d658acc04589731078ef9 100644 |
--- a/media/filters/chunk_demuxer.h |
+++ b/media/filters/chunk_demuxer.h |
@@ -92,8 +92,8 @@ class MEDIA_EXPORT ChunkDemuxerStream : public DemuxerStream { |
TextTrackConfig text_track_config(); |
// Sets the memory limit, in bytes, on the SourceBufferStream. |
- void set_memory_limit_for_testing(int memory_limit) { |
- stream_->set_memory_limit_for_testing(memory_limit); |
+ void set_memory_limit(int memory_limit) { |
+ stream_->set_memory_limit(memory_limit); |
} |
bool supports_partial_append_window_trimming() const { |
@@ -262,9 +262,10 @@ class MEDIA_EXPORT ChunkDemuxer : public Demuxer { |
void Shutdown(); |
- // Sets the memory limit on each stream. |memory_limit| is the |
- // maximum number of bytes each stream is allowed to hold in its buffer. |
- void SetMemoryLimitsForTesting(int memory_limit); |
+ // Sets the memory limit on each stream of a specific type. |
+ // |memory_limit| is the maximum number of bytes each stream of type |type| |
+ // is allowed to hold in its buffer. |
+ void SetMemoryLimits(DemuxerStream::Type type, int memory_limit); |
// Returns the ranges representing the buffered data in the demuxer. |
// TODO(wolenetz): Remove this method once MediaSourceDelegate no longer |